# Generated by Django 2.2.18 on 2021-03-11 20:11

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0120_auto_20210221_2206'),
    ]

    operations = [
        migrations.AlterField(
            model_name='negative',
            name='teleconverter',
            field=models.ForeignKey(blank=True, help_text='Teleconverter used when taking this negative', null=True, on_delete=django.db.models.deletion.CASCADE, to='schema.Teleconverter'),
        ),
    ]
