# Generated by Django 2.2.17 on 2020-12-11 20:19

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0113_auto_20201127_2102'),
    ]

    operations = [
        migrations.AddField(
            model_name='bulkfilm',
            name='finished',
            field=models.BooleanField(default=False, help_text='Whether this bulk film has been used up'),
        ),
        migrations.AddField(
            model_name='bulkfilm',
            name='length',
            field=models.PositiveIntegerField(blank=True, help_text='Length of bulk film roll', null=True),
        ),
    ]
