# Generated by Django 2.2 on 2020-03-27 23:03

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0049_auto_20200327_2231'),
    ]

    operations = [
        migrations.RenameField(
            model_name='cameramodel',
            old_name='lens_model',
            new_name='lens_model_name',
        ),
        migrations.RemoveField(
            model_name='camera',
            name='lens',
        ),
        migrations.RemoveField(
            model_name='cameramodel',
            name='fixed_mount',
        ),
        migrations.RemoveField(
            model_name='cameramodel',
            name='lensmodel',
        ),
        migrations.RemoveField(
            model_name='lensmodel',
            name='fixed_mount',
        ),
    ]
