# Generated by Django 2.2.4 on 2019-10-16 11:06

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0011_auto_20191016_1035'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='projector',
            name='manufacturer',
        ),
        migrations.RemoveField(
            model_name='projector',
            name='mount',
        ),
        migrations.RemoveField(
            model_name='projector',
            name='negative_size',
        ),
        migrations.RemoveField(
            model_name='projector',
            name='owner',
        ),
        migrations.AlterField(
            model_name='accessory',
            name='type',
            field=models.CharField(choices=[('Battery grip', 'Battery grip'), ('Case', 'Case'), ('Film back', 'Film back'), ('Focusing screen', 'Focusing screen'), ('Lens hood', 'Lens hood'), ('Lens cap', 'Lens cap'), (
                'Power winder', 'Power winder'), ('Viewfinder', 'Viewfinder'), ('Rangefinder', 'Rangefinder'), ('Projector', 'Projector'), ('Light meter', 'Light meter')], help_text='Type of accessory', max_length=15),
        ),
        migrations.DeleteModel(
            name='LightMeter',
        ),
        migrations.DeleteModel(
            name='Projector',
        ),
    ]
