{% extends "base.html" %}
{% load crispy_forms_tags %}

{% block heading %}{% include "heading.html" %}{%endblock%}

{% block subheading %}<h2>Add new</h2>{%endblock%}

{% block content %}
{% crispy form %}
{% endblock %}
