# Generated by Django 2.2.12 on 2020-05-14 11:20

import autosequence.fields
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0055_auto_20200514_0912'),
    ]

    operations = [
        migrations.AlterField(
            model_name='accessory',
            name='id_owner',
            field=autosequence.fields.AutoSequenceField(unique_with=('owner',), verbose_name='ID'),
        ),
        migrations.AlterField(
            model_name='archive',
            name='id_owner',
            field=autosequence.fields.AutoSequenceField(unique_with=('owner',), verbose_name='ID'),
        ),
        migrations.AlterField(
            model_name='bulkfilm',
            name='id_owner',
            field=autosequence.fields.AutoSequenceField(unique_with=('owner',), verbose_name='ID'),
        ),
        migrations.AlterField(
            model_name='camera',
            name='id_owner',
            field=autosequence.fields.AutoSequenceField(unique_with=('owner',), verbose_name='ID'),
        ),
        migrations.AlterField(
            model_name='enlarger',
            name='id_owner',
            field=autosequence.fields.AutoSequenceField(unique_with=('owner',), verbose_name='ID'),
        ),
        migrations.AlterField(
            model_name='film',
            name='id_owner',
            field=autosequence.fields.AutoSequenceField(unique_with=('owner',), verbose_name='ID'),
        ),
        migrations.AlterField(
            model_name='flash',
            name='id_owner',
            field=autosequence.fields.AutoSequenceField(unique_with=('owner',), verbose_name='ID'),
        ),
        migrations.AlterField(
            model_name='lens',
            name='id_owner',
            field=autosequence.fields.AutoSequenceField(unique_with=('owner',), verbose_name='ID'),
        ),
        migrations.AlterField(
            model_name='mountadapter',
            name='id_owner',
            field=autosequence.fields.AutoSequenceField(unique_with=('owner',), verbose_name='ID'),
        ),
        migrations.AlterField(
            model_name='negative',
            name='id_owner',
            field=autosequence.fields.AutoSequenceField(unique_with=('owner',), verbose_name='ID'),
        ),
        migrations.AlterField(
            model_name='order',
            name='id_owner',
            field=autosequence.fields.AutoSequenceField(unique_with=('owner',), verbose_name='ID'),
        ),
        migrations.AlterField(
            model_name='person',
            name='id_owner',
            field=autosequence.fields.AutoSequenceField(unique_with=('owner',), verbose_name='ID'),
        ),
        migrations.AlterField(
            model_name='print',
            name='id_owner',
            field=autosequence.fields.AutoSequenceField(unique_with=('owner',), verbose_name='ID'),
        ),
        migrations.AlterField(
            model_name='repair',
            name='id_owner',
            field=autosequence.fields.AutoSequenceField(unique_with=('owner',), verbose_name='ID'),
        ),
        migrations.AlterField(
            model_name='scan',
            name='id_owner',
            field=autosequence.fields.AutoSequenceField(unique_with=('owner',), verbose_name='ID'),
        ),
        migrations.AlterField(
            model_name='teleconverter',
            name='id_owner',
            field=autosequence.fields.AutoSequenceField(unique_with=('owner',), verbose_name='ID'),
        ),
    ]
