# Generated by Django 2.2.20 on 2021-04-28 19:18

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0123_auto_20210417_1920'),
    ]

    operations = [
        migrations.AddField(
            model_name='cameramodel',
            name='dx_code',
            field=models.BooleanField(blank=True, help_text='Whether the camera can read DX codes with Camera Auto Sensing', null=True, verbose_name='DX code'),
        ),
        migrations.AddField(
            model_name='historicalcameramodel',
            name='dx_code',
            field=models.BooleanField(blank=True, help_text='Whether the camera can read DX codes with Camera Auto Sensing', null=True, verbose_name='DX code'),
        ),
    ]
