# Generated by Django 2.2.16 on 2020-10-21 16:14

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0092_negative_location'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='negative',
            name='latitude',
        ),
        migrations.RemoveField(
            model_name='negative',
            name='longitude',
        ),
    ]
