# Generated by Django 2.2.16 on 2020-10-28 21:17

from django.db import migrations, models
import uuid


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0097_auto_20201024_1959'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='scan',
            name='colour',
        ),
        migrations.RemoveField(
            model_name='scan',
            name='height',
        ),
        migrations.RemoveField(
            model_name='scan',
            name='id',
        ),
        migrations.RemoveField(
            model_name='scan',
            name='id_owner',
        ),
        migrations.RemoveField(
            model_name='scan',
            name='width',
        ),
        migrations.AddField(
            model_name='scan',
            name='uuid',
            field=models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False),
        ),
    ]
