# Generated by Django 2.2.20 on 2021-04-11 19:02

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0121_auto_20210311_2011'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='bulkfilm',
            options={'ordering': ['id_owner'], 'verbose_name_plural': 'bulk films'},
        ),
        migrations.AlterModelOptions(
            name='condition',
            options={'ordering': ['min_rating'], 'verbose_name_plural': 'conditions'},
        ),
        migrations.AlterModelOptions(
            name='flash',
            options={'ordering': ['id_owner'], 'verbose_name_plural': 'flashes'},
        ),
        migrations.AlterModelOptions(
            name='print',
            options={'ordering': ['id_owner'], 'verbose_name_plural': 'prints'},
        ),
        migrations.AlterModelOptions(
            name='scan',
            options={'ordering': ['uuid'], 'verbose_name_plural': 'scans'},
        ),
        migrations.AlterModelOptions(
            name='teleconverter',
            options={'ordering': ['id_owner'], 'verbose_name_plural': 'teleconverters'},
        ),
    ]
