# Generated by Django 2.2.16 on 2020-11-07 20:37

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0099_auto_20201106_2117'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='film',
            name='directory',
        ),
    ]
