# Generated by Django 2.2.17 on 2020-11-16 21:33

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0103_auto_20201110_2200'),
    ]

    operations = [
        migrations.DeleteModel(
            name='Repair',
        ),
    ]
