# Generated by Django 2.2.20 on 2021-04-17 19:20

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0122_auto_20210411_1902'),
    ]

    operations = [
        migrations.AlterField(
            model_name='cameramodel',
            name='lens_model_name',
            field=models.CharField(blank=True, help_text='Model name of this lens', max_length=45, null=True, verbose_name='lens model'),
        ),
        migrations.AlterField(
            model_name='cameramodel',
            name='manufacturer',
            field=models.ForeignKey(help_text='Manufacturer of this camera model', on_delete=django.db.models.deletion.CASCADE, to='schema.Manufacturer', verbose_name='manufacturer'),
        ),
        migrations.AlterField(
            model_name='cameramodel',
            name='mount',
            field=models.ForeignKey(blank=True, help_text='Lens mount used by this camera model', limit_choices_to={'purpose': 'Camera'}, null=True, on_delete=django.db.models.deletion.CASCADE, to='schema.Mount', verbose_name='mount'),
        ),
        migrations.AlterField(
            model_name='historicalcameramodel',
            name='lens_model_name',
            field=models.CharField(blank=True, help_text='Model name of this lens', max_length=45, null=True, verbose_name='lens model'),
        ),
        migrations.AlterField(
            model_name='historicalcameramodel',
            name='manufacturer',
            field=models.ForeignKey(blank=True, db_constraint=False, help_text='Manufacturer of this camera model', null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to='schema.Manufacturer', verbose_name='manufacturer'),
        ),
        migrations.AlterField(
            model_name='historicalcameramodel',
            name='mount',
            field=models.ForeignKey(blank=True, db_constraint=False, help_text='Lens mount used by this camera model', limit_choices_to={'purpose': 'Camera'}, null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to='schema.Mount', verbose_name='mount'),
        ),
    ]
