# Generated by Django 2.2 on 2020-03-21 21:15

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0037_auto_20200321_2101'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='cameramodel',
            unique_together=set(),
        ),
        migrations.AddConstraint(
            model_name='cameramodel',
            constraint=models.UniqueConstraint(fields=(
                'manufacturer', 'model', 'disambiguation'), name='cameramodel_unique_name'),
        ),
    ]
