# Generated by Django 2.2.9 on 2020-03-17 13:44

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0029_remove_paperstock_tonable'),
    ]

    operations = [
        migrations.AlterField(
            model_name='paperstock',
            name='finish',
            field=models.CharField(blank=True, choices=[('Matt', 'Matt'), ('Gloss', 'Gloss'), ('Satin', 'Satin'), ('Semi gloss', 'Semi gloss'), (
                'Pearl', 'Pearl'), ('Lustre', 'Lustre')], help_text='The finish of the paper surface', max_length=25, null=True),
        ),
    ]
