# Generated by Django 2.2.17 on 2020-12-16 20:13

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0115_auto_20201212_2131'),
    ]

    operations = [
        migrations.AlterField(
            model_name='negative',
            name='flash',
            field=models.BooleanField(default=False, help_text='Whether flash was used'),
        ),
    ]
