# Generated by Django 2.2.14 on 2020-08-28 20:47

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0080_populate_shutter'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='cameramodel',
            name='shutter_speeds',
        ),
    ]
