# Generated by Django 2.2.4 on 2020-01-10 17:36

import autosequence.fields
from django.db import migrations


class Migration(migrations.Migration):

    replaces = [('schema', '0019_auto_20200110_1728'),
                ('schema', '0020_auto_20200110_1734')]

    dependencies = [
        ('schema', '0018_auto_20191217_2303'),
    ]

    operations = [
        migrations.AlterField(
            model_name='archive',
            name='id_owner',
            field=autosequence.fields.AutoSequenceField(
                unique_with=('owner',)),
        ),
        migrations.AlterField(
            model_name='accessory',
            name='id_owner',
            field=autosequence.fields.AutoSequenceField(
                unique_with=('owner',)),
        ),
        migrations.AlterField(
            model_name='bulkfilm',
            name='id_owner',
            field=autosequence.fields.AutoSequenceField(
                unique_with=('owner',)),
        ),
        migrations.AlterField(
            model_name='camera',
            name='id_owner',
            field=autosequence.fields.AutoSequenceField(
                unique_with=('owner',)),
        ),
        migrations.AlterField(
            model_name='enlarger',
            name='id_owner',
            field=autosequence.fields.AutoSequenceField(
                unique_with=('owner',)),
        ),
        migrations.AlterField(
            model_name='film',
            name='id_owner',
            field=autosequence.fields.AutoSequenceField(
                unique_with=('owner',)),
        ),
        migrations.AlterField(
            model_name='filter',
            name='id_owner',
            field=autosequence.fields.AutoSequenceField(
                unique_with=('owner',)),
        ),
        migrations.AlterField(
            model_name='flash',
            name='id_owner',
            field=autosequence.fields.AutoSequenceField(
                unique_with=('owner',)),
        ),
        migrations.AlterField(
            model_name='lens',
            name='id_owner',
            field=autosequence.fields.AutoSequenceField(
                unique_with=('owner',)),
        ),
        migrations.AlterField(
            model_name='mountadapter',
            name='id_owner',
            field=autosequence.fields.AutoSequenceField(
                unique_with=('owner',)),
        ),
        migrations.AlterField(
            model_name='negative',
            name='id_owner',
            field=autosequence.fields.AutoSequenceField(
                unique_with=('owner',)),
        ),
        migrations.AlterField(
            model_name='order',
            name='id_owner',
            field=autosequence.fields.AutoSequenceField(
                unique_with=('owner',)),
        ),
        migrations.AlterField(
            model_name='person',
            name='id_owner',
            field=autosequence.fields.AutoSequenceField(
                unique_with=('owner',)),
        ),
        migrations.AlterField(
            model_name='print',
            name='id_owner',
            field=autosequence.fields.AutoSequenceField(
                unique_with=('owner',)),
        ),
        migrations.AlterField(
            model_name='repair',
            name='id_owner',
            field=autosequence.fields.AutoSequenceField(
                unique_with=('owner',)),
        ),
        migrations.AlterField(
            model_name='scan',
            name='id_owner',
            field=autosequence.fields.AutoSequenceField(
                unique_with=('owner',)),
        ),
        migrations.AlterField(
            model_name='series',
            name='id_owner',
            field=autosequence.fields.AutoSequenceField(
                unique_with=('owner',)),
        ),
        migrations.AlterField(
            model_name='teleconverter',
            name='id_owner',
            field=autosequence.fields.AutoSequenceField(
                unique_with=('owner',)),
        ),
        migrations.AlterUniqueTogether(
            name='accessory',
            unique_together=set(),
        ),
        migrations.AlterUniqueTogether(
            name='archive',
            unique_together=set(),
        ),
        migrations.AlterUniqueTogether(
            name='bulkfilm',
            unique_together=set(),
        ),
        migrations.AlterUniqueTogether(
            name='camera',
            unique_together={('cameramodel', 'serial')},
        ),
        migrations.AlterUniqueTogether(
            name='enlarger',
            unique_together=set(),
        ),
        migrations.AlterUniqueTogether(
            name='film',
            unique_together=set(),
        ),
        migrations.AlterUniqueTogether(
            name='filter',
            unique_together=set(),
        ),
        migrations.AlterUniqueTogether(
            name='flash',
            unique_together=set(),
        ),
        migrations.AlterUniqueTogether(
            name='lens',
            unique_together={('lensmodel', 'serial')},
        ),
        migrations.AlterUniqueTogether(
            name='mountadapter',
            unique_together=set(),
        ),
        migrations.AlterUniqueTogether(
            name='negative',
            unique_together={('film', 'frame')},
        ),
        migrations.AlterUniqueTogether(
            name='order',
            unique_together=set(),
        ),
        migrations.AlterUniqueTogether(
            name='person',
            unique_together=set(),
        ),
        migrations.AlterUniqueTogether(
            name='print',
            unique_together=set(),
        ),
        migrations.AlterUniqueTogether(
            name='repair',
            unique_together=set(),
        ),
        migrations.AlterUniqueTogether(
            name='scan',
            unique_together=set(),
        ),
        migrations.AlterUniqueTogether(
            name='series',
            unique_together=set(),
        ),
        migrations.AlterUniqueTogether(
            name='teleconverter',
            unique_together=set(),
        ),
    ]
