# Generated by Django 2.2.16 on 2020-10-12 18:34

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0089_auto_20201009_1926'),
    ]

    operations = [
        migrations.AddField(
            model_name='film',
            name='status',
            field=models.CharField(choices=[('Available', 'Available'), ('Loaded', 'Loaded'), ('Developed', 'Developed'), ('Archived', 'Archived')], default='Available', help_text='Status of this film', max_length=9),
        ),
    ]
