# Generated by Django 2.2 on 2020-03-04 20:20

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0022_auto_20200229_1954'),
    ]

    operations = [
        migrations.AlterField(
            model_name='cameramodel',
            name='meter_min_ev',
            field=models.IntegerField(
                blank=True, help_text='Lowest EV/LV the built-in meter supports', null=True, verbose_name='Min EV'),
        ),
    ]
