# Generated by Django 2.2.9 on 2020-03-17 13:40

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0028_cameramodel_x_sync'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='paperstock',
            name='tonable',
        ),
    ]
