{% extends "detail.html" %}

{% block content %}
<table class="table table-hover">
  <tr>
    <td>Name</td>
    <td>{{ object.name }}</td>
  </tr>
  <tr>
    <td>Type</td>
    <td>{{ object.type }}</td>
  </tr>
</table>
{% endblock %}
