# Generated by Django 2.2.14 on 2020-09-22 19:29

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0084_auto_20200905_1952'),
    ]

    operations = [
        migrations.AddField(
            model_name='historicallensmodel',
            name='perspective_control',
            field=models.BooleanField(blank=True, help_text='Whether this lens has perspective control / tilt-shift', null=True),
        ),
        migrations.AddField(
            model_name='lensmodel',
            name='perspective_control',
            field=models.BooleanField(blank=True, help_text='Whether this lens has perspective control / tilt-shift', null=True),
        ),
    ]
