<!DOCTYPE html>
<html lang="en">

<head>
    <link rel="stylesheet" href="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css"
        integrity="sha384-JcKb8q3iqJ61gNV9KGb8thSsNjpSL0n8PARn9HuZOnIxN0hoP+VmmDGMN5t9UJ0Z" crossorigin="anonymous">
    <title>CameraHub</title>
</head>

<body>
    <div class="container">
        <div class="row">
            <div class="col-md-12">
                <div class="error-template">
                    <h1><img src="/static/svg/camera.svg" style="max-width:128px" alt="CameraHub"></h1>
                    <h2>{% block errorcode %}{% endblock %}</h2>
                    <div class="error-details">
                        {% block errortext %}{% endblock %}
                    </div>
                    <div class="error-actions"><a href="/">Back to CameraHub</a></div>
                </div>
            </div>
        </div>
    </div>
</body>

</html>
