# Generated by Django 2.2.16 on 2020-11-10 22:00

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0102_slugs'),
    ]

    operations = [
        migrations.RenameField(
            model_name='cameramodel',
            old_name='url',
            new_name='linkurl',
        ),
        migrations.RenameField(
            model_name='historicalcameramodel',
            old_name='url',
            new_name='linkurl',
        ),
        migrations.RenameField(
            model_name='historicallensmodel',
            old_name='url',
            new_name='linkurl',
        ),
        migrations.RenameField(
            model_name='historicalmanufacturer',
            old_name='url',
            new_name='linkurl',
        ),
        migrations.RenameField(
            model_name='lensmodel',
            old_name='url',
            new_name='linkurl',
        ),
        migrations.RenameField(
            model_name='manufacturer',
            old_name='url',
            new_name='linkurl',
        ),
    ]
