# Generated by Django 2.2.16 on 2020-10-22 13:14

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0093_auto_20201021_1614'),
    ]

    operations = [
        migrations.AlterField(
            model_name='cameramodel',
            name='disambiguation',
            field=models.CharField(blank=True, default='', help_text='Distinguishing notes for camera models with the same name', max_length=45),
        ),
        migrations.AlterField(
            model_name='historicalcameramodel',
            name='disambiguation',
            field=models.CharField(blank=True, default='', help_text='Distinguishing notes for camera models with the same name', max_length=45),
        ),
        migrations.AlterField(
            model_name='historicallensmodel',
            name='disambiguation',
            field=models.CharField(blank=True, default='', help_text='Distinguishing notes for lens models with the same name', max_length=45),
        ),
        migrations.AlterField(
            model_name='lensmodel',
            name='disambiguation',
            field=models.CharField(blank=True, default='', help_text='Distinguishing notes for lens models with the same name', max_length=45),
        ),
    ]
