# Generated by Django 2.2.16 on 2020-10-24 19:41

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0095_auto_20201023_2111'),
    ]

    operations = [
        migrations.AlterField(
            model_name='camera',
            name='own',
            field=models.BooleanField(default=True, help_text='Whether the camera is currently in your collection'),
        ),
        migrations.AlterField(
            model_name='flash',
            name='own',
            field=models.BooleanField(default=True, help_text='Whether the flash is currently in your collection'),
        ),
        migrations.AlterField(
            model_name='lens',
            name='own',
            field=models.BooleanField(default=True, help_text='Whether the lens is currently in your collection'),
        ),
        migrations.AlterField(
            model_name='print',
            name='own',
            field=models.BooleanField(default=True, help_text='Whether the print is currently in your collection'),
        ),
    ]
