# Generated by Django 2.2.17 on 2020-11-26 13:50

from django.conf import settings
from django.db import migrations


class Migration(migrations.Migration):
    atomic = False

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('schema', '0107_auto_20201124_1955'),
    ]

    operations = [
        migrations.RenameModel(
            old_name='Flash',
            new_name='FlashModel',
        ),
    ]
