# Generated by Django 2.2.18 on 2021-02-21 22:06

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0119_auto_20210216_2046'),
    ]

    operations = [
        migrations.AlterField(
            model_name='cameramodel',
            name='image_attribution_link',
            field=models.URLField(blank=True, help_text='Attribution link for this image', null=True),
        ),
        migrations.AlterField(
            model_name='cameramodel',
            name='link',
            field=models.URLField(blank=True, help_text='Link to more information about this camera model', null=True),
        ),
        migrations.AlterField(
            model_name='enlargermodel',
            name='image_attribution_link',
            field=models.URLField(blank=True, help_text='Attribution link for this image', null=True),
        ),
        migrations.AlterField(
            model_name='flashmodel',
            name='image_attribution_link',
            field=models.URLField(blank=True, help_text='Attribution link for this image', null=True),
        ),
        migrations.AlterField(
            model_name='historicalcameramodel',
            name='image_attribution_link',
            field=models.URLField(blank=True, help_text='Attribution link for this image', null=True),
        ),
        migrations.AlterField(
            model_name='historicalcameramodel',
            name='link',
            field=models.URLField(blank=True, help_text='Link to more information about this camera model', null=True),
        ),
        migrations.AlterField(
            model_name='historicalenlargermodel',
            name='image_attribution_link',
            field=models.URLField(blank=True, help_text='Attribution link for this image', null=True),
        ),
        migrations.AlterField(
            model_name='historicalflashmodel',
            name='image_attribution_link',
            field=models.URLField(blank=True, help_text='Attribution link for this image', null=True),
        ),
        migrations.AlterField(
            model_name='historicallensmodel',
            name='diagram_attribution_link',
            field=models.URLField(blank=True, help_text='Attribution link for this diagram', null=True),
        ),
        migrations.AlterField(
            model_name='historicallensmodel',
            name='image_attribution_link',
            field=models.URLField(blank=True, help_text='Attribution link for this image', null=True),
        ),
        migrations.AlterField(
            model_name='historicallensmodel',
            name='link',
            field=models.URLField(blank=True, help_text='Link to more information about this lens', null=True),
        ),
        migrations.AlterField(
            model_name='historicalmanufacturer',
            name='link',
            field=models.URLField(blank=True, help_text='Link to the manufacturers main website', max_length=45, null=True),
        ),
        migrations.AlterField(
            model_name='historicalteleconvertermodel',
            name='image_attribution_link',
            field=models.URLField(blank=True, help_text='Attribution link for this image', null=True),
        ),
        migrations.AlterField(
            model_name='lensmodel',
            name='diagram_attribution_link',
            field=models.URLField(blank=True, help_text='Attribution link for this diagram', null=True),
        ),
        migrations.AlterField(
            model_name='lensmodel',
            name='image_attribution_link',
            field=models.URLField(blank=True, help_text='Attribution link for this image', null=True),
        ),
        migrations.AlterField(
            model_name='lensmodel',
            name='link',
            field=models.URLField(blank=True, help_text='Link to more information about this lens', null=True),
        ),
        migrations.AlterField(
            model_name='manufacturer',
            name='link',
            field=models.URLField(blank=True, help_text='Link to the manufacturers main website', max_length=45, null=True),
        ),
        migrations.AlterField(
            model_name='teleconvertermodel',
            name='image_attribution_link',
            field=models.URLField(blank=True, help_text='Attribution link for this image', null=True),
        ),
    ]
