# Generated by Django 2.2.4 on 2019-10-16 10:35

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0010_auto_20191016_1023'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='cameramodel',
            name='digital',
        ),
        migrations.RemoveField(
            model_name='flash',
            name='dslr_safe',
        ),
        migrations.RemoveField(
            model_name='format',
            name='digital',
        ),
        migrations.RemoveField(
            model_name='mount',
            name='digital_only',
        ),
    ]
