# Generated by Django 2.2.14 on 2020-08-25 19:20

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0074_auto_20200820_2003'),
    ]

    operations = [
        migrations.AlterField(
            model_name='cameramodel',
            name='pc_sync',
            field=models.BooleanField(blank=True, help_text='Whether the camera has a PC sync socket for flash (sometimes known as a German socket)', null=True, verbose_name='PC sync'),
        ),
        migrations.AlterField(
            model_name='historicalcameramodel',
            name='pc_sync',
            field=models.BooleanField(blank=True, help_text='Whether the camera has a PC sync socket for flash (sometimes known as a German socket)', null=True, verbose_name='PC sync'),
        ),
    ]
