{% extends "print.html" %}

{% block content %}
<table border="1">
  {% if object.filmstock is not None %}
  <tr>
    <td>Filmstock</td>
    <td>{{ object.filmstock }}</td>
  </tr>
  {% endif %}
  {% if object.bulk_film is not None %}
  <tr>
    <td>Bulk film</td>
    <td>{{ object.bulk_film }}</td>
  </tr>
  {% endif %}

  {% if object.camera is not None %}
  <tr>
    <td>Camera</td>
    <td>{{ object.camera }}</td>
  </tr>
  {% endif %}
  {% if object.frames is not None %}
  <tr>
    <td>Frames</td>
    <td>{{ object.frames }}</td>
  </tr>
  {% endif %}
  {% if object.exposed_at is not None %}
  <tr>
    <td>Exposed at</td>
    <td>ISO {{ object.exposed_at }}{% if object.pushed %} <small><em>Film was pushed</em></small>{% elif object.pulled %} <small><em>Film was pulled</em></small>{% endif %}</td>
  </tr>
  {% endif %}

  {% if object.developer is not None %}
  <tr>
    <td>Developer</td>
    <td>{{ object.developer }}</td>
  </tr>
  {% endif %}
  {% if object.date_processed is not None %}
  <tr>
    <td>Date processed</td>
    <td>{{ object.date_processed }} {% if object.expired_when_loaded %}Film was expired when processed">{% endif %}</td>
  </tr>
  {% endif %}
  {% if object.developer_previous_uses is not None %}
  <tr>
    <td>Developer uses</td>
    <td>{{ object.developer_previous_uses }}</td>
  </tr>
  {% endif %}
  {% if object.development_time is not None %}
  <tr>
    <td>Development time</td>
    <td>{{ object.development_time }}</td>
  </tr>
  {% endif %}
  {% if object.development_temperature is not None %}
  <tr>
    <td>Development temperature</td>
    <td>{{ object.development_temperature }}°C</td>
  </tr>
  {% endif %}
  {% if object.development_notes %}
  <tr>
    <td>Development notes</td>
    <td>{{ object.development_notes|linebreaks }}</td>
  </tr>
  {% endif %}
  {% if object.processed_by is not None %}
  <tr>
    <td>Processed by</td>
    <td>{{ object.processed_by }}</td>
  </tr>
  {% endif %}

</table>



{% if film.negative_set.all %}
<h4>Negatives</h4>
<table border="1">
  <tr>
    <th>Frame</th>
    <th>Caption</th>
    <th>Date</th>
    <th>Aperture</th>
    <th>Shutter speed</th>
  </tr>
  {% for negative in film.negative_set.all %}
  <tr>
    <td>{{ negative.frame|default_if_none:"" }}</td>
    <td>{{ negative.caption|default_if_none:"" }}</td>
    <td>{{ negative.date|default_if_none:"" }}</td>
    <td>{{ negative.aperture|default_if_none:"" }}</td>
    <td>{{ negative.shutter_speed|default_if_none:"" }}</td>
  </tr>
  {% endfor %}
</table>
{% endif %}

{% endblock %}
