# Generated by Django 2.2.16 on 2020-10-02 18:25

import collectionfield.models.fields
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0086_auto_20200930_1924'),
    ]

    operations = [
        migrations.AddField(
            model_name='cameramodel',
            name='other_names',
            field=collectionfield.models.fields.CollectionField(blank=True, help_text='Other model names that this camera may be known by, e.g. in other parts of the world. Separate with commas.', null=True),
        ),
        migrations.AddField(
            model_name='historicalcameramodel',
            name='other_names',
            field=collectionfield.models.fields.CollectionField(blank=True, help_text='Other model names that this camera may be known by, e.g. in other parts of the world. Separate with commas.', null=True),
        ),
    ]
