{% extends "detail.html" %}
{% load static %}
{% load boolicontag %}

{% block content %}
<table class="table table-hover">
  <tr>
    <th colspan="2" id="summary"><img src="{% static "svg/summary.svg" %}" width="30" height="30" alt="Summary">&nbsp;<a
        href="#">Summary</a></th>
  </tr>
  <tr>
    <td>Archive name</td>
    <td>{{ object.name }}</td>
  </tr>
  <tr>
    <td>Archive type</td>
    <td>{{ object.type }}</td>
  </tr>
  {% if object.max_width is not None %}
  <tr>
    <td>Max object size</td>
    <td>{{ object.max_width }}&times;{{ object.max_height }}"</td>
  </tr>
  {% endif %}
  {% if object.location is not None %}
  <tr>
    <td>Location</td>
    <td>{{ object.location }}</td>
  </tr>
  {% endif %}
  {% if object.storage is not None %}
  <tr>
    <td>Storage</td>
    <td>{{ object.storage }}</td>
  </tr>
  {% endif %}
  <tr>
    <td>Sealed</td>
    <td>{{ object.sealed|boolicontag }}</td>
  </tr>
</table>
{% endblock %}

{% block moreactions %}
{% if object.sealed %}<li><a class="btn btn-primary" href="{% url 'schema:archive-print' object.id_owner %}"
  target="_blank" role="button">Print a cover sheet</a></li>{% endif %}
{%endblock%}
