# Generated by Django 2.2 on 2020-03-21 22:36

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0038_auto_20200321_2115'),
    ]

    operations = [
        migrations.AddField(
            model_name='battery',
            name='slug',
            field=models.SlugField(editable=False, null=True, unique=True),
        ),
        migrations.AddField(
            model_name='developer',
            name='slug',
            field=models.SlugField(editable=False, null=True, unique=True),
        ),
        migrations.AddField(
            model_name='filmstock',
            name='slug',
            field=models.SlugField(editable=False, null=True, unique=True),
        ),
        migrations.AddField(
            model_name='lensmodel',
            name='slug',
            field=models.SlugField(editable=False, null=True, unique=True),
        ),
        migrations.AddField(
            model_name='manufacturer',
            name='slug',
            field=models.SlugField(editable=False, null=True, unique=True),
        ),
        migrations.AddField(
            model_name='mount',
            name='slug',
            field=models.SlugField(editable=False, null=True, unique=True),
        ),
        migrations.AddField(
            model_name='toner',
            name='slug',
            field=models.SlugField(editable=False, null=True, unique=True),
        ),
    ]
