# Generated by Django 2.2.9 on 2020-03-24 08:39

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import django_currentuser.db.models.fields
import django_currentuser.middleware


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('schema', '0047_auto_20200323_2236'),
    ]

    operations = [
        migrations.AddField(
            model_name='battery',
            name='created_at',
            field=models.DateTimeField(auto_now_add=True, null=True),
        ),
        migrations.AddField(
            model_name='battery',
            name='created_by',
            field=django_currentuser.db.models.fields.CurrentUserField(default=django_currentuser.middleware.get_current_authenticated_user,
                                                                       editable=False, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='battery_created_by', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='battery',
            name='updated_at',
            field=models.DateTimeField(auto_now=True, null=True),
        ),
        migrations.AddField(
            model_name='battery',
            name='updated_by',
            field=django_currentuser.db.models.fields.CurrentUserField(default=django_currentuser.middleware.get_current_authenticated_user, null=True,
                                                                       on_delete=django.db.models.deletion.CASCADE, on_update=True, related_name='battery_updated_by', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='developer',
            name='created_at',
            field=models.DateTimeField(auto_now_add=True, null=True),
        ),
        migrations.AddField(
            model_name='developer',
            name='created_by',
            field=django_currentuser.db.models.fields.CurrentUserField(default=django_currentuser.middleware.get_current_authenticated_user, editable=False,
                                                                       null=True, on_delete=django.db.models.deletion.CASCADE, related_name='developer_created_by', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='developer',
            name='updated_at',
            field=models.DateTimeField(auto_now=True, null=True),
        ),
        migrations.AddField(
            model_name='developer',
            name='updated_by',
            field=django_currentuser.db.models.fields.CurrentUserField(default=django_currentuser.middleware.get_current_authenticated_user, null=True,
                                                                       on_delete=django.db.models.deletion.CASCADE, on_update=True, related_name='developer_updated_by', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='filmstock',
            name='created_at',
            field=models.DateTimeField(auto_now_add=True, null=True),
        ),
        migrations.AddField(
            model_name='filmstock',
            name='created_by',
            field=django_currentuser.db.models.fields.CurrentUserField(default=django_currentuser.middleware.get_current_authenticated_user, editable=False,
                                                                       null=True, on_delete=django.db.models.deletion.CASCADE, related_name='filmstock_created_by', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='filmstock',
            name='updated_at',
            field=models.DateTimeField(auto_now=True, null=True),
        ),
        migrations.AddField(
            model_name='filmstock',
            name='updated_by',
            field=django_currentuser.db.models.fields.CurrentUserField(default=django_currentuser.middleware.get_current_authenticated_user, null=True,
                                                                       on_delete=django.db.models.deletion.CASCADE, on_update=True, related_name='filmstock_updated_by', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='flashprotocol',
            name='created_at',
            field=models.DateTimeField(auto_now_add=True, null=True),
        ),
        migrations.AddField(
            model_name='flashprotocol',
            name='created_by',
            field=django_currentuser.db.models.fields.CurrentUserField(default=django_currentuser.middleware.get_current_authenticated_user, editable=False,
                                                                       null=True, on_delete=django.db.models.deletion.CASCADE, related_name='flashprotocol_created_by', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='flashprotocol',
            name='updated_at',
            field=models.DateTimeField(auto_now=True, null=True),
        ),
        migrations.AddField(
            model_name='flashprotocol',
            name='updated_by',
            field=django_currentuser.db.models.fields.CurrentUserField(default=django_currentuser.middleware.get_current_authenticated_user, null=True,
                                                                       on_delete=django.db.models.deletion.CASCADE, on_update=True, related_name='flashprotocol_updated_by', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='format',
            name='created_at',
            field=models.DateTimeField(auto_now_add=True, null=True),
        ),
        migrations.AddField(
            model_name='format',
            name='created_by',
            field=django_currentuser.db.models.fields.CurrentUserField(default=django_currentuser.middleware.get_current_authenticated_user,
                                                                       editable=False, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='format_created_by', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='format',
            name='updated_at',
            field=models.DateTimeField(auto_now=True, null=True),
        ),
        migrations.AddField(
            model_name='format',
            name='updated_by',
            field=django_currentuser.db.models.fields.CurrentUserField(default=django_currentuser.middleware.get_current_authenticated_user, null=True,
                                                                       on_delete=django.db.models.deletion.CASCADE, on_update=True, related_name='format_updated_by', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='manufacturer',
            name='created_at',
            field=models.DateTimeField(auto_now_add=True, null=True),
        ),
        migrations.AddField(
            model_name='manufacturer',
            name='created_by',
            field=django_currentuser.db.models.fields.CurrentUserField(default=django_currentuser.middleware.get_current_authenticated_user, editable=False,
                                                                       null=True, on_delete=django.db.models.deletion.CASCADE, related_name='manufacturer_created_by', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='manufacturer',
            name='updated_at',
            field=models.DateTimeField(auto_now=True, null=True),
        ),
        migrations.AddField(
            model_name='manufacturer',
            name='updated_by',
            field=django_currentuser.db.models.fields.CurrentUserField(default=django_currentuser.middleware.get_current_authenticated_user, null=True,
                                                                       on_delete=django.db.models.deletion.CASCADE, on_update=True, related_name='manufacturer_updated_by', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='mount',
            name='created_at',
            field=models.DateTimeField(auto_now_add=True, null=True),
        ),
        migrations.AddField(
            model_name='mount',
            name='created_by',
            field=django_currentuser.db.models.fields.CurrentUserField(default=django_currentuser.middleware.get_current_authenticated_user,
                                                                       editable=False, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='mount_created_by', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='mount',
            name='updated_at',
            field=models.DateTimeField(auto_now=True, null=True),
        ),
        migrations.AddField(
            model_name='mount',
            name='updated_by',
            field=django_currentuser.db.models.fields.CurrentUserField(default=django_currentuser.middleware.get_current_authenticated_user, null=True,
                                                                       on_delete=django.db.models.deletion.CASCADE, on_update=True, related_name='mount_updated_by', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='negativesize',
            name='created_at',
            field=models.DateTimeField(auto_now_add=True, null=True),
        ),
        migrations.AddField(
            model_name='negativesize',
            name='created_by',
            field=django_currentuser.db.models.fields.CurrentUserField(default=django_currentuser.middleware.get_current_authenticated_user, editable=False,
                                                                       null=True, on_delete=django.db.models.deletion.CASCADE, related_name='negativesize_created_by', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='negativesize',
            name='updated_at',
            field=models.DateTimeField(auto_now=True, null=True),
        ),
        migrations.AddField(
            model_name='negativesize',
            name='updated_by',
            field=django_currentuser.db.models.fields.CurrentUserField(default=django_currentuser.middleware.get_current_authenticated_user, null=True,
                                                                       on_delete=django.db.models.deletion.CASCADE, on_update=True, related_name='negativesize_updated_by', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='paperstock',
            name='created_at',
            field=models.DateTimeField(auto_now_add=True, null=True),
        ),
        migrations.AddField(
            model_name='paperstock',
            name='created_by',
            field=django_currentuser.db.models.fields.CurrentUserField(default=django_currentuser.middleware.get_current_authenticated_user, editable=False,
                                                                       null=True, on_delete=django.db.models.deletion.CASCADE, related_name='paperstock_created_by', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='paperstock',
            name='updated_at',
            field=models.DateTimeField(auto_now=True, null=True),
        ),
        migrations.AddField(
            model_name='paperstock',
            name='updated_by',
            field=django_currentuser.db.models.fields.CurrentUserField(default=django_currentuser.middleware.get_current_authenticated_user, null=True,
                                                                       on_delete=django.db.models.deletion.CASCADE, on_update=True, related_name='paperstock_updated_by', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='toner',
            name='created_at',
            field=models.DateTimeField(auto_now_add=True, null=True),
        ),
        migrations.AddField(
            model_name='toner',
            name='created_by',
            field=django_currentuser.db.models.fields.CurrentUserField(default=django_currentuser.middleware.get_current_authenticated_user,
                                                                       editable=False, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='toner_created_by', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='toner',
            name='updated_at',
            field=models.DateTimeField(auto_now=True, null=True),
        ),
        migrations.AddField(
            model_name='toner',
            name='updated_by',
            field=django_currentuser.db.models.fields.CurrentUserField(default=django_currentuser.middleware.get_current_authenticated_user, null=True,
                                                                       on_delete=django.db.models.deletion.CASCADE, on_update=True, related_name='toner_updated_by', to=settings.AUTH_USER_MODEL),
        ),
    ]
