# Generated by Django 2.2.9 on 2020-03-05 10:14

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0024_cameramodel_shoe'),
    ]

    operations = [
    ]
