{% extends "detail.html" %}
{% load static %}

{% block content %}
<table class="table table-hover">
  <tr>
    <th colspan="2" id="summary"><img src="{% static "svg/summary.svg" %}" width="30" height="30" alt="Summary">&nbsp;<a
        href="#">Summary</a></th>
  </tr>
  {% if object.negative is not None %}
  <tr>
    <td>Negative</td>
    <td><a href="{% url 'schema:negative-detail' object.negative.slug %}">{{ object.negative }}</a></td>
  </tr>
  {% endif %}
  <tr>
    <td>Size</td>
    <td>{{ object.width }} &times; {{ object.height }}</td>
  </tr>
  {% if object.added is not None %}
  <tr>
    <td>Date added</td>
    <td>{{ object.added }}</td>
  </tr>
  {% endif %}
  {% if object.printed is not None %}
  <tr>
    <td>Date printed</td>
    <td>{{ object.printed }}</td>
  </tr>
  {% endif %}
  {% if object.print is not None %}
  <tr>
    <td>Print</td>
    <td>{{ object.print }}</td>
  </tr>
  {% endif %}
  {% if object.recipient is not None %}
  <tr>
    <td>Recipient</td>
    <td>{{ object.recipient }}</td>
  </tr>
  {% endif %}
</table>
{% endblock %}
